/*********************************************************************
*                   (c) SEGGER Microcontroller GmbH                  *
*                        The Embedded Experts                        *
*                           www.segger.com                           *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------

File    : main.c
Purpose : Generic application start

*/

#define LED (9)

#define CCM_BASE_ADDR  (0x400FC000u)
#define CCM_CCGR1      (*(volatile unsigned int*)(CCM_BASE_ADDR + 0x6C))
#define CCM_CCGR4      (*(volatile unsigned int*)(CCM_BASE_ADDR + 0x78))

#define IOMUXC_BASE_ADDR                     (0x401F8000u)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO_AD_B0_09  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x0E0))
#define IOMUXC_SW_PAD_CTL_PAD_GPIO_AD_B0_09  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x2D0))

#define GPIO_BASE_ADDR  (0x401B8000u)
#define GPIO_DR         (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x0))
#define GPIO_DIR        (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x4))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       _InitLED()
*/
void _InitLED(void) {
  CCM_CCGR4 |= (0x3u << 2);                      // Enable iomuxc clock 
  CCM_CCGR1 &= ~(0x3u << 26);                     // Disable gpio1 clock
  IOMUXC_SW_MUX_CTL_PAD_GPIO_AD_B0_09 = 0x5; //(0x1u << 4);     // Set mux to JTAG_TDI
  IOMUXC_SW_PAD_CTL_PAD_GPIO_AD_B0_09 = 0x10B0;  // Functional properties
  CCM_CCGR1 |= (0x3u << 26);                     // Enable gpio1 clock
  GPIO_DR |= (0x1u << LED);
  GPIO_DIR |= (0x1u << LED);  // Set GPIO pin 9 to output
}

/*********************************************************************
*
*       _SetLED()
*/
void _SetLED(int Index) {
  if (Index == 0) {
    GPIO_DR &= ~(0x1u << LED);
  }
}

/*********************************************************************
*
*       _ClrLED()
*/
void _ClrLED(int Index) {
  if (Index == 0) {
    GPIO_DR |= (0x1u << LED);
  }
}

/*********************************************************************
*
*       _ToggleLED()
*/
void _ToggleLED(int Index) {
  if (Index == 0) {
    GPIO_DR ^= (0x1u << LED);
  }
}

/*********************************************************************
*
*       _Delay()
*/
void _Delay(volatile int Delay) {
  while (--Delay);
}


/*********************************************************************
*
*       main()
*
*  Function description
*   Application entry point.
*/
void main(void) {

  _InitLED();
  do {
    _ToggleLED(0);
    _Delay(0x1000000);
  } while (1);
}

/*************************** End of file ****************************/
